bottomWidget property
you can pass an additional widget that will display on the bottom of the list
Implementation
final Widget? bottomWidget;
you can pass an additional widget that will display on the bottom of the list
final Widget? bottomWidget;