builder property
builder will BuildContext and itemData as a single item.
and it will expect a widget that will represent a single item
Implementation
final ItemBuilder<T> builder;
builder will BuildContext and itemData as a single item.
and it will expect a widget that will represent a single item
final ItemBuilder<T> builder;