onLoadMoreLoading property

Widget? onLoadMoreLoading
final

onLoadMoreLoading is a widget at end of the list that will display when waiting for a response on a pagination API request

Implementation

final Widget? onLoadMoreLoading;